@@ -1,4 +1,4 @@
-from .config import default_args, default_args
+from .config import default_ap, default_args
 from .data import ETDataset, ETDataLoader
 from .easytorch import EasyTorch
 from .metrics import ETMetrics, ETAverages, Prf1a, ConfusionMatrix
