@@ -258,8 +258,6 @@ class ETTrainer:
         return eval_avg, eval_metrics
 
     def _reduce_iteration(self, its):
-        if len(its) == 1:
-            return its[0]
         reduced = {}.fromkeys(its[0].keys(), None)
         for key in reduced:
             if isinstance(its[0][key], _base_metrics.ETAverages):
